@@ -26,6 +26,10 @@ def runBB(train=True, predict=False):
 
     param = load_parameters(file_path+base_param_name,param_types)
 
+    if not (dt_string is None):
+        del param['dim3']
+        del param['HP_network_num']
+        del param['S_half']
     
     if not train:
         param['HP_train_epochs'] = 0
