@@ -1,4 +1,7 @@
 from createdir import runBB
 
 if __name__ == "__main__": 
-    runBB() 
+    runBB(train=True) 
+
+
+'predict_images'
\ No newline at end of file
